pub fn compute_mac(
keys: &SessionKeys,
seq: u64,
payload: &[u8],
aad: &[u8],
) -> Result<Vec<u8>, CryptoError>Expand description
Compute an authentication tag for a control payload using the derived control key.
pub fn compute_mac(
keys: &SessionKeys,
seq: u64,
payload: &[u8],
aad: &[u8],
) -> Result<Vec<u8>, CryptoError>Compute an authentication tag for a control payload using the derived control key.